@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Get XML.
 has xml => (
@@ -38,9 +38,11 @@ Map::Tube::Vienna - Interface to the Vienna U-Bahn Map.
  use Map::Tube::Vienna;
  my $obj = Map::Tube::Vienna->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
  my $route = $obj->get_shortest_route($from, $to);
+ my $stations_ar = $obj->get_stations($line);
  my $metro_name = $obj->name;
  my $xml_file = $obj->xml;
 
@@ -64,6 +66,11 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_lines()>
+
+ Get lines in metro map.
+ Returns reference to array with Map::Tube::Line objects.
+
 =item C<get_node_by_id($station_id)>
 
  Get station node by id.
@@ -79,6 +86,11 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
  Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
  Returns Map::Tube::Route object.
 
+=item C<get_stations($line)>
+
+ Get list of stations for concrete metro line.
+ Returns reference to array with Map::Tube::Node objects.
+
 =item C<name()>
 
  Get metro name.
@@ -151,9 +163,8 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
          'callback_node' => \&node_color_without_label,
-         'driver' => 'neato',
          'tube' => $obj,
- ); 
+ );
 
  # Get graph to file.
  $g->graph('Vienna.png');
@@ -162,11 +173,13 @@ For more information about Vienna Map, click L<here|https://en.wikipedia.org/wik
  system "ls -l Vienna.png";
 
  # Output like:
- # -rw-r--r-- 1 skim skim 292500 Dec 21 17:25 Vienna.png
+ # -rw-r--r-- 1 skim skim 294217 Jan 25 01:11 Vienna.png
 
 =begin html
 
-<img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Vienna/master/images/Vienna.png" alt="U-Bahn Wien" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Vienna/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Vienna/master/images/ex3.png" alt="U-Bahn Wien" width="300px" height="300px" />
+</a>
 
 =end html
 
@@ -180,8 +193,11 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
-L<Map::Tube::Text::Table>.
+L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Table>,
+L<Task::Map::Tube>.
 
 L<Map::Tube::Barcelona>,
 L<Map::Tube::Berlin>,
@@ -217,12 +233,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014 Michal Špaček
+ © 2014-2015 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
